ReturnCode

Enum ReturnCode 

#[repr(i32)]
pub enum ReturnCode {
Show 13 variants Success = 0, CalleeTrapped = 1, CalleeReverted = 2, KeyNotFound = 3, BelowSubsistenceThreshold = 4, TransferFailed = 5, NewContractNotFunded = 6, CodeNotFound = 7, NotCallable = 8, LoggingDisabled = 9, CallRuntimeReturnedError = 10, EcdsaRecoverFailed = 11, UnExpectedReturnCode = 12,
}

Variants



Success = 0

API call successful.



CalleeTrapped = 1

The called function trapped and has its state changes reverted. In this case no output buffer is returned.



CalleeReverted = 2

The called function ran to completion but decided to revert its state. An output buffer is returned when one was supplied.



KeyNotFound = 3

The passed key does not exist in storage.



BelowSubsistenceThreshold = 4

Transfer failed because it would have brought the sender’s total balance below the subsistence threshold.



TransferFailed = 5

Transfer failed for other reasons. Most probably reserved or locked balance of the sender prevents the transfer.



NewContractNotFunded = 6

The newly created contract is below the subsistence threshold after executing its constructor.



CodeNotFound = 7

No code could be found at the supplied code hash.



NotCallable = 8

The contract that was called is either no contract at all (a plain account) or is a tombstone.



LoggingDisabled = 9

The call to seal_debug_message had no effect because debug message recording was disabled.



CallRuntimeReturnedError = 10

The call dispatched by seal_call_runtime was executed but returned an error.



EcdsaRecoverFailed = 11

ECDSA pubkey recovery failed. Most probably wrong recovery id or signature.



UnExpectedReturnCode = 12

Unexpected return code